ete2.phylomedb

Package ete2 :: Package phylomedb |
[hide private]
[frames] | no frames]

# Source Code for Package ete2.phylomedb

     1  __VERSION__="ete2-2.0rev90"
     2  # #START_LICENSE###########################################################
     3  #
     4  # Copyright (C) 2009 by Jaime Huerta Cepas. All rights reserved.
     5  # email: jhcepas@gmail.com
     6  #
     7  # This file is part of the Environment for Tree Exploration program (ETE).
     8  # http://ete.cgenomics.org
     9  #
    10  # ETE is free software: you can redistribute it and/or modify it
    11  # under the terms of the GNU General Public License as published by
    12  # the Free Software Foundation, either version 3 of the License, or
    13  # (at your option) any later version.
    14  #
    15  # ETE is distributed in the hope that it will be useful,
    16  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    17  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    18  # GNU General Public License for more details.
    19  #
    20  # You should have received a copy of the GNU General Public License
    21  # along with ETE.  If not, see <http://www.gnu.org/licenses/>.
    22  #
    23  # #END_LICENSE#############################################################
    24
    25
    26  species_ages = {}
    27
    28  _humanv1 = {
    29  # Basal eukariotes
    30  "Ath":10, # Arabidopsis thaliana
    31  "Cre":10,
    32  "Pfa":10,
    33  "Pyo":10,
    34  "Ddi":10,
    35  "Gth":10,
    36  "Lma":10, # leismania
    37  "Pte":10,
    38
    39  # Fungi
    40  "Ago":9,
    41  "Cal":9,
    42  "Cgl":9,
    43  "Cne":9,
    44  "Dha":9,
    45  "Ecu":9,
    46  "Gze":9,
    47  "Kla":9,
    48  "Ncr":9,
    49  "Sce":9, # S.cerevisiae
    50  "Spb":9,
    51  "Yli":9,
    52
    53  # metazoa non chordates
    54  "Aga":8, # Anopheles
    55  "Dme":8, # Drosophila melanogaster
    56  "Ame":8, # Apis meliferae
    57  "Cel":8, # Caenorabditis elegans
    58  "Cbr":8, # Caenorabditis brigssae
    59
    60  # chordates non vertebrates
    61  "Cin":7, # Ciona intestinalis
    62
    63  # vertebrates non tetrapodes
    64  "Dre":6, # Danio rerio
    65  "Tni":6, # Tetraodom
    66  "Fru":6, # Fugu rubripes
    67
    68  # tetrapodes non birds nor mammals
    69  "Xtr":5, # Xenopus
    70
    71  # birds
    72  "Gga":4, # Chicken
    73
    74  # Mammals non primates
    75  "Mdo":3, # Monodelphis domestica
    76  "Mms":3, # Mouse
    77  "Rno":3, # Rat
    78  "Cfa":3, # Dog
    79  "Bta":3, # Cow
    80
    81  # primates non hominids
    82  "Ptr":2, # chimp
    83  "Mmu":2, # Macaca
    84
    85  # hominids
    86  "Hsa":1, # human
    87  }
    88  species_ages["human_phylome"] = _humanv1
    89